function Nu = Nusselt(T,parameters)
%Nu = Nusselt(Tvec,parameters)
%computes heat spatiall averaged heat flux
%   Nu = 1 - k_{zn}T_{m0,n}
%for a given matrix T_{mn} of Fourier coefficients, constructed from the
%nx*ny-by-1 vector Tvec as
%   T_{mn} = reshape(T,nx,ny)
%Here nx and ny as well as k_{zn} = n*pi are supplied as part of the
%parameters structure, and m0 =  ceil((nx+1)/2);
%
%Input arguments:
%   T:  solution vector T of complex Fourier coefficients
%   parameters: parameter structure for which the solution vector was
%   computed
%Output argument:
%   Nu: the corresponding Nusselt number

%reshaping and indexing information
nx = parameters.nx;
ny = parameters.ny;
mm0 = ceil((nx+1)/2);

%wavenumber matrix
K_z = parameters.K_z;

%derivative
Tz = K_z*T;
Tz = reshape(Tz,nx,ny);

%Nusselt number
Nu = 1-sum(Tz(mm0,:));



