function Tshift = phaseshift(T,parameters)
%Ashift = phaseshift(A_vec,parameters)
%   Assume Avec is an nx*ny-by-1 vector from which we construct an nx-by-ny
%   matrix A_{mn} by
%   A = reshape(A_vec,nx,ny). Let m0 = = ceil((nx+1)/2) and assume 
%   A_{mm0-m,n} = conj(A_{mm+m,n}
%   in which case A_{mn} can be treated as the Fourier transform of a
%   real-valued matrix M, computed through
%   A = ifftshift(A,1);
%   M = nx*ifft(T_mat);
%   phaseshift computes the phase shift necessary to make the the Fourier
%   transform of M have an M_{2,1} component with vanishing real part, and
%   then reconsititutes the corresponding matrix A with the phase shift
%   applied, and recomputes the vector Ashift as reshape(A,nx*ny,1). The
%   phsae shift is designed to make sure that initial guesses used in
%   solving for roots of convectino_steady_Ra_real satisfy the phase
%   ambiguity constraint described in the file header for
%   convction_steady_ra_real
%
%   Specifically, we form
%       A = reshpae(A_vec,nx,ny)
%   extract the required phase angle
%       theta = atan(imag(A(mm0+1,1)/real(A(mm0+1,1))
%   form a phase shift matrix
%       shift(mm,nn) = exp(i*(mm-m0)*(pi/2-thetea))
%   and multiply
%       A = A.*shift
%   and then re-form the vector
%       Ashift = reshape(A,nx*ny,1)
%
%Input argument:

%k_x = 0 mode
nx = parameters.nx;
mm0 = ceil((nx+1)/2);

%wavenumber matrix
K_x = parameters.K_x;
k_x = spdiags(K_x,0);

%identify phase shift
dxnormal = ( pi/2 - atan(imag(T(mm0+1))/real(T(mm0+1))) )/ k_x(mm0+1);
shiftvec = exp(1i*k_x*dxnormal);

%shifted solution Fourier coefficients
Tshift = T.*shiftvec;


end

